@@ -1,13 +1,11 @@
 package HTTP::Message::PSGI;
 use strict;
 use warnings;
-use parent qw(Exporter);
+use base qw(Exporter);
 our @EXPORT = qw( req_to_psgi res_from_psgi );
 
 use Carp ();
 use URI::Escape ();
-use Plack::Util;
-use Try::Tiny;
 
 my $TRUE  = (1 == 1);
 my $FALSE = !$TRUE;
@@ -15,7 +13,7 @@ my $FALSE = !$TRUE;
 sub req_to_psgi {
     my $req = shift;
 
-    unless (try { $req->isa('HTTP::Request') }) {
+    unless (eval { $req->isa('HTTP::Request') }) {
         Carp::croak("Request is not HTTP::Request: $req");
     }
 
@@ -26,12 +24,7 @@ sub req_to_psgi {
     $uri->host('localhost') unless $uri->host;
     $uri->port(80)          unless $uri->port;
     $uri->host_port($host)  unless !$host || ( $host eq $uri->host_port );
-
-    # STUPID: If the request URI is utf-8 decoded, methods like ->path
-    # and ->host returns decoded strings in ascii, which causes double
-    # encoded strings in uri_unescape and URI concatenation in
-    # Plack::Request :/
-    utf8::downgrade $$uri;
+    $uri = $uri->canonical;
 
     open my $input, "<", \do { $req->content };
 
@@ -47,15 +40,13 @@ sub req_to_psgi {
         REMOTE_PORT       => int( rand(64000) + 1000 ),                   # not in RFC 3875
         REQUEST_URI       => $uri->path_query,                            # not in RFC 3875
         REQUEST_METHOD    => $req->method,
-        'psgi.version'      => [ 1, 1 ],
+        'psgi.version'      => [ 1, 0 ],
         'psgi.url_scheme'   => $uri->scheme eq 'https' ? 'https' : 'http',
         'psgi.input'        => $input,
         'psgi.errors'       => *STDERR,
         'psgi.multithread'  => $FALSE,
         'psgi.multiprocess' => $FALSE,
         'psgi.run_once'     => $TRUE,
-        'psgi.streaming'    => $TRUE,
-        'psgi.nonblocking'  => $FALSE,
         @_,
     };
 
@@ -78,57 +69,25 @@ sub req_to_psgi {
 }
 
 sub res_from_psgi {
-    my ($psgi_res) = @_;
+    my($status, $headers, $body) = @{+shift};
+    my $res = HTTP::Response->new($status);
+    $res->headers->header(@$headers) if @$headers;
 
-    my $res;
-    if (ref $psgi_res eq 'ARRAY') {
-        _res_from_psgi($psgi_res, \$res);
-    }
-    elsif (ref $psgi_res eq 'CODE') {
-        $psgi_res->(sub {
-            _res_from_psgi($_[0], \$res);
-        });
+    if (ref $body eq 'ARRAY') {
+        $res->content(join '', @$body);
+    } else {
+        local $/ = \4096;
+        my $content;
+        while (defined(my $buf = $body->getline)) {
+            $content .= $buf;
+        }
+        $body->close;
+        $res->content($content);
     }
 
     return $res;
 }
 
-sub _res_from_psgi {
-    my ($status, $headers, $body) = @{+shift};
-    my $res_ref = shift;
-
-    my $convert_resp = sub {
-        my $res = HTTP::Response->new($status);
-        $res->headers->header(@$headers) if @$headers;
-
-        if (ref $body eq 'ARRAY') {
-            $res->content(join '', @$body);
-        } else {
-            local $/ = \4096;
-            my $content;
-            while (defined(my $buf = $body->getline)) {
-                $content .= $buf;
-            }
-            $body->close;
-            $res->content($content);
-        }
-
-        ${ $res_ref } = $res;
-
-        return;
-    };
-
-    if (!defined $body) {
-        my $o = Plack::Util::inline_object
-            write => sub { push @{ $body ||= [] }, @_ },
-            close => $convert_resp;
-
-        return $o;
-    }
-
-    $convert_resp->();
-}
-
 sub HTTP::Request::to_psgi {
     req_to_psgi(@_);
 }
@@ -175,7 +134,7 @@ L<Plack::Response>.
 
   my $env = req_to_psgi($req [, $key => $val ... ]);
 
-Converts HTTP::Request object into PSGI env hash reference.
+Converts HTTP::Response object into PSGI env hash reference.
 
 =item HTTP::Request::to_psgi
 
