@@ -1,8 +1,8 @@
 package Plack::App::FCGIDispatcher;
 use strict;
 use warnings;
-use parent qw(Plack::Component);
-use Plack::Util::Accessor qw(host port socket);
+use base qw(Plack::Middleware);
+__PACKAGE__->mk_accessors(qw(host port socket));
 
 use FCGI::Client;
 use HTTP::Response;
@@ -31,19 +31,7 @@ sub call {
 
     my $conn = FCGI::Client::Connection->new(sock => $sock);
     my $input = delete $env->{'psgi.input'};
-
-    my $content_in = '';
-    if (my $cl = $env->{CONTENT_LENGTH}) {
-        while ($cl > 0) {
-            my $read = $input->read($content_in, $cl, length $content_in);
-            $cl -= $read;
-        }
-    }
-
-    for my $key (keys %$env) {
-        delete $env->{$key} if $key =~ /^psgi\./;
-    }
-
+    my $content_in = do { local $/; <$input> };
     my ($stdout, $stderr) = $conn->request(
         $env,
         $content_in,
@@ -90,7 +78,7 @@ Plack::App::FCGIDispatcher - Dispatch requests to FCGI servers
   use Plack::App::FCGIDispatcher;
   my $app = Plack::App::FCGIDispatcher->new({
       port => 8080, # FastCGI daemon port
-  })->to_app;
+  });
 
 =head1 DESCRIPTION
 
@@ -105,7 +93,7 @@ a PSGI application to dispatch requests to external FCGI servers.
 
   my $app = Plack::App::FCGIDispatcher->new({
       host => '127.0.0.1', port => 8080,
-  })->to_app;
+  });
 
 Specifies host and port where FastCGI daemon is listening. host defaults to C<127.0.0.1>.
 
@@ -113,7 +101,7 @@ Specifies host and port where FastCGI daemon is listening. host defaults to C<12
 
   my $app = Plack::App::FCGIDispatcher->new({
       socket => "/tmp/fcgi.sock",
-  })->to_app;
+  });
 
 Specifies UNIX socket path where FastCGI daemon is listening.
 
