@@ -1,7 +1,7 @@
 package Plack::Middleware::AccessLog::Timed;
 use strict;
 use warnings;
-use parent qw( Plack::Middleware::AccessLog );
+use base qw( Plack::Middleware::AccessLog );
 
 use Time::HiRes;
 use Plack::Util;
@@ -14,35 +14,25 @@ sub call {
     my $length = 0;
     my $logger = $self->logger || sub { $env->{'psgi.errors'}->print(@_) };
 
-    my $res = $self->app->($env);
+    my($status, $header, $body) = @{$self->app->($env)};
 
-    return $self->response_cb($res, sub {
-        my $res = shift;
-        my($status, $header, $body) = @$res;
+    my $getline = ref $body eq 'ARRAY' ? sub { shift @$body } : { $body->getline };
 
-        if (!defined $body) {
-            $logger->( $self->log_line($status, $header, $env) );
-            return;
-        }
+    my $timer_body = Plack::Util::inline_object(
+        getline => sub {
+            my $line = $getline->();
+            $length += length $line if defined $line;
+            return $line;
+        },
+        close => sub {
+            $body->close if ref $body ne 'ARRAY';
 
-        my $getline = ref $body eq 'ARRAY' ? sub { shift @$body } : sub { $body->getline };
+            my $now = Time::HiRes::gettimeofday;
+            $logger->( $self->log_line($status, $header, $env, { time => $now - $time, content_length => $length }) );
+        },
+    );
 
-        my $timer_body = Plack::Util::inline_object(
-            getline => sub {
-                my $line = $getline->();
-                $length += length $line if defined $line;
-                return $line;
-            },
-            close => sub {
-                $body->close if ref $body ne 'ARRAY';
-
-                my $now = Time::HiRes::gettimeofday;
-                $logger->( $self->log_line($status, $header, $env, { time => $now - $time, content_length => $length }) );
-            },
-        );
-
-        @$res = ($status, $header, $timer_body);
-    });
+    return [ $status, $header, $timer_body ];
 }
 
 1;
@@ -60,7 +50,7 @@ Plack::Middleware::AccessLog::Timed - Logs requests with time and accurate body
 
   builder {
       enable "Plack::Middleware::AccessLog::Timed",
-          format => "%v %h %l %u %t \"%r\" %>s %b %D";
+          format => ""%v %h %l %u %t \"%r\" %>s %b %D";
       $app;
   };
 
