@@ -1,17 +1,16 @@
 package Plack::Middleware::StackTrace;
 use strict;
 use warnings;
-use parent qw/Plack::Middleware/;
+use base qw/Plack::Middleware/;
 use Plack;
 use Plack::Util;
 use Devel::StackTrace;
 use Devel::StackTrace::AsHTML;
-use Try::Tiny;
 
 our $StackTraceClass = "Devel::StackTrace";
 
 # Optional since it needs PadWalker
-if (try { require Devel::StackTrace::WithLexicals; 1 }) {
+if (eval { require Devel::StackTrace::WithLexicals; 1 }) {
     $StackTraceClass = "Devel::StackTrace::WithLexicals";
 }
 
@@ -24,18 +23,16 @@ sub call {
         die @_;
     };
 
-    my $res = try { $self->app->($env) };
+    my $res = do {
+        local $@;
+        eval { $self->app->($env) };
+    };
 
-    if ($trace && (!$res or $res->[0] == 500)) {
+    if (!$res && $trace) {
         my $body = $trace->as_html;
         $res = [500, ['Content-Type' => 'text/html; charset=utf-8'], [ $body ]];
     }
 
-    # break $trace here since $SIG{__DIE__} holds the ref to it, and
-    # $trace has refs to Standalone.pm's args ($conn etc.) and
-    # prevents garbage collection to be happening.
-    undef $trace;
-
     return $res;
 }
 
