@@ -1,10 +1,10 @@
 package Plack::Middleware::Static;
 use strict;
 use warnings;
-use parent qw/Plack::Middleware/;
+use base qw/Plack::Middleware/;
 use Plack::App::File;
 
-use Plack::Util::Accessor qw( path root encoding );
+__PACKAGE__->mk_accessors(qw( path root ));
 
 sub call {
     my $self = shift;
@@ -33,9 +33,8 @@ sub _handle_static {
         $_;
     } or return;
 
-    $self->{file} ||= Plack::App::File->new({ root => $self->root || '.', encoding => $self->encoding });
-    local $env->{PATH_INFO} = $path; # rewrite PATH
-    return $self->{file}->call($env);
+    $self->{file} ||= Plack::App::File->new({ root => $self->root || '.' });
+    return $self->{file}->call({ %$env, PATH_INFO => $path }) # rewrite PATH
 }
 
 1;
@@ -67,7 +66,7 @@ traversal) or the file is there but not readable, this middleware will
 return a 403 Forbidden response.
 
 The content type returned will be determined from the file extension
-based on L<Plack::MIME>.
+based on L<MIME::Types>.
 
 =head1 CONFIGURATIONS
 
