@@ -7,7 +7,7 @@ use Test::More;
 use IO::Socket;
 use File::Spec;
 use Test::TCP qw/test_tcp empty_port/;
-use parent qw/Exporter/;
+use base qw/Exporter/;
 
 # this file is copied from Catalyst. thanks!
 
@@ -35,8 +35,7 @@ sub test_fcgi_standalone {
         },
         client => sub {
             $callback->($http_port, $fcgi_port);
-        },
-        port => $http_port,
+        }
     );
 }
 
@@ -53,14 +52,11 @@ sub test_lighty_external (&@) {
     plan skip_all => 'Please set LIGHTTPD_BIN to the path to lighttpd'
         unless $lighttpd_bin && -x $lighttpd_bin;
 
-    my $ver = (`$lighttpd_bin -v` =~ /lighttpd-1.(\d+\.\d+)/)[0];
-    diag "Testing with lighttpd 1.$ver";
-
     my $tmpdir = File::Temp::tempdir( CLEANUP => 1 );
 
     test_tcp(
         client => sub {
-            $callback->($lighty_port, $fcgi_port, ($ver && $ver < 4.23));
+            $callback->($lighty_port, $fcgi_port);
             warn `cat $tmpdir/error.log` if $ENV{DEBUG};
         },
         server => sub {
@@ -92,22 +88,32 @@ sub _render_conf {
     my ($tmpdir, $port, $fcgiport) = @_;
     <<"END";
 # basic lighttpd config file for testing fcgi(external server)+Plack
-server.modules += ("mod_fastcgi")
+server.modules = (
+    "mod_access",
+    "mod_fastcgi",
+    "mod_accesslog"
+)
 
 server.document-root = "$tmpdir"
 
+server.errorlog    = "$tmpdir/error.log"
+accesslog.filename = "$tmpdir/access.log"
+
 server.bind = "127.0.0.1"
 server.port = $port
 
 # HTTP::Engine app specific fcgi setup
 fastcgi.server = (
-    "" => ((
+    "" => (
+        "FastCgiTest" => (
             "check-local"     => "disable",
             "host"            => "127.0.0.1",
             "port"            => $fcgiport,
+            "min-procs"       => 1,
+            "max-procs"       => 1,
             "idle-timeout"    => 20,
-            "fix-root-scriptname" => "enable", # for 1.4.23 or later
-    ))
+        )
+    )
 )
 END
 }
